@@ -1,7 +1,7 @@
 /*
   Copyright(C) 2010 Tetsuro IKEDA
-  Copyright(C) 2010-2011 Kentoku SHIBA
-  Copyright(C) 2011 Kouhei Sutou <kou@clear-code.com>
+  Copyright(C) 2010-2012 Kentoku SHIBA
+  Copyright(C) 2011-2012 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -385,6 +385,8 @@ private:
   void clear_cursor_geo();
   void clear_search_result();
   void clear_search_result_geo();
+  void clear_indexes();
+  void remove_grn_obj_force(const char *name);
   grn_obj *find_tokenizer(const char *name, int name_length);
   int wrapper_get_next_record(uchar *buf);
   int storage_get_next_record(uchar *buf);
@@ -399,8 +401,46 @@ private:
   void check_fast_order_limit(grn_table_sort_key **sort_keys, int *n_sort_keys,
                               longlong *limit,
                               grn_obj *target_table, grn_obj *score_column);
-  void store_to_field(grn_obj *col, grn_id id, Field *field);
-  void store_to_fields_from_primary_table(uchar *buf, grn_id record_id);
+
+  int generic_store_bulk_string(Field *field, grn_obj *buf);
+  int generic_store_bulk_integer(Field *field, grn_obj *buf);
+  int generic_store_bulk_float(Field *field, grn_obj *buf);
+  int generic_store_bulk_timestamp(Field *field, grn_obj *buf);
+  int generic_store_bulk_date(Field *field, grn_obj *buf);
+  int generic_store_bulk_time(Field *field, grn_obj *buf);
+  int generic_store_bulk_datetime(Field *field, grn_obj *buf);
+  int generic_store_bulk_new_date(Field *field, grn_obj *buf);
+  int generic_store_bulk_new_decimal(Field *field, grn_obj *buf);
+  int generic_store_bulk_blob(Field *field, grn_obj *buf);
+  int generic_store_bulk_geometry(Field *field, grn_obj *buf);
+  int generic_store_bulk(Field *field, grn_obj *buf);
+
+  void storage_store_field_string(Field *field,
+                                  const char *value, uint value_length);
+  void storage_store_field_integer(Field *field,
+                                   const char *value, uint value_length);
+  void storage_store_field_float(Field *field,
+                                 const char *value, uint value_length);
+  void storage_store_field_timestamp(Field *field,
+                                     const char *value, uint value_length);
+  void storage_store_field_date(Field *field,
+                                const char *value, uint value_length);
+  void storage_store_field_time(Field *field,
+                                const char *value, uint value_length);
+  void storage_store_field_datetime(Field *field,
+                                    const char *value, uint value_length);
+  void storage_store_field_new_date(Field *field,
+                                    const char *value, uint value_length);
+  void storage_store_field_blob(Field *field,
+                                const char *value, uint value_length);
+  void storage_store_field_geometry(Field *field,
+                                    const char *value, uint value_length);
+  void storage_store_field(Field *field, const char *value, uint value_length);
+  void storage_store_fields(uchar *buf, grn_id record_id);
+  void storage_store_fields_by_index(uchar *buf);
+
+  int storage_encode_key(Field *field, const uchar *key, uchar *buf, uint *size);
+
   void set_pk_bitmap();
   int wrapper_create(const char *name, TABLE *table,
                      HA_CREATE_INFO *info, MRN_SHARE *tmp_share);
@@ -439,7 +479,7 @@ private:
   int storage_delete_table(const char *name, MRN_SHARE *tmp_share,
                            const char *table_name);
   int wrapper_open(const char *name, int mode, uint test_if_locked);
-  int wrapper_open_indexes(const char *name);
+  int wrapper_open_indexes(const char *name, bool ignore_open_error);
   int storage_open(const char *name, int mode, uint test_if_locked);
   int open_table(const char *name);
   int storage_open_columns(void);
@@ -656,6 +696,7 @@ private:
   int storage_enable_indexes(uint mode);
   int wrapper_check(THD* thd, HA_CHECK_OPT* check_opt);
   int storage_check(THD* thd, HA_CHECK_OPT* check_opt);
+  int wrapper_recreate_indexes(THD *thd);
   int wrapper_repair(THD* thd, HA_CHECK_OPT* check_opt);
   int storage_repair(THD* thd, HA_CHECK_OPT* check_opt);
   bool wrapper_check_and_repair(THD *thd);
